| Title: | Clean the R Console and Environment |
|---|---|
| Description: | Small package to clean the R console and the R environment with the call of just one function. |
| Authors: | Jonathan M. Mang [aut, cre] (ORCID: <https://orcid.org/0000-0003-0518-4710>), MIRACUM - Medical Informatics in Research and Care in University Medicine [fnd], Universitätsklinikum Erlangen, Germany [cph] |
| Maintainer: | Jonathan M. Mang <[email protected]> |
| License: | GPL-3 |
| Version: | 0.0.1 |
| Built: | 2026-05-19 05:54:09 UTC |
| Source: | https://github.com/joundso/clear |
Function to clean the local environment. The call of this function clears the console and the local environment variables.
clear(keep_environment = FALSE, keep_console = FALSE)clear(keep_environment = FALSE, keep_console = FALSE)
keep_environment |
(Optional, boolean) If true, the objects from the environment will not be deleted/emptied. |
keep_console |
(Optional, boolean) If true, the console will not be emptied. |
Nothing.