Welcome to ClientVPS Mirrors

Help for package cleaR
Title: Clean the R Console and Environment
Version: 0.0.4
Date: 2022-07-19
Description: Small package to clean the R console and the R environment with the call of just one function.
License: GPL-3
URL: https://github.com/joundso/cleaR
BugReports: https://github.com/joundso/cleaR/issues
Depends: R (≥ 3.1.0)
Suggests: lintr, testthat
Encoding: UTF-8
Language: en-US
NeedsCompilation: no
Packaged: 2022-07-19 13:22:20 UTC; user
Author: Jonathan M. Mang ORCID iD [aut, cre], MIRACUM - Medical Informatics in Research and Care in University Medicine [fnd], Universitätsklinikum Erlangen, Germany [cph]
Maintainer: Jonathan M. Mang <jonathan.mang@uk-erlangen.de>
Repository: CRAN
Date/Publication: 2022-07-19 13:40:02 UTC

Clean the console and environment-variables

Description

Function to clean the local environment. The call of this function clears the console and the local environment variables.

Usage

clear(keep_environment = FALSE, keep_console = FALSE, fast = FALSE)

Arguments

keep_environment

(Optional, boolean) If true, the objects from the environment will not be deleted/emptied.

keep_console

(Optional, boolean) If true, the console will not be emptied.

fast

(Optional, boolean) If true, 'gctorture(TRUE)' will NOT be applied which will speedup the function call. For more information see ?gctorture.

Value

Nothing.

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.